JSDoc: Class: ScaleEditor

# Class: ScaleEditor

## SlickGridScale.ScaleEditor

Scale

This class represents a range editor defined by the SlickGrid project. Note, this object is heavily based on classes in slick.editors.js and in the documentation that can be found here.

## Constructor

#### new ScaleEditor(args)

##### Parameters:

Name | Type | Description
--- | --- | ---
`args` | Object | Arguments passed by SlickGrid.

Source:
  - scale-editor.js, line 26

### Members

#### (inner) $input :Node

Node containing the jQuery slider

##### Type:

- Node

Source:
  - scale-editor.js, line 31

#### (inner) $parentDiv :Node

Node containing the parent div holding the slider info

##### Type:

- Node

Source:
  - scale-editor.js, line 36

#### (inner) $viewval :Node

Node containing the textbox for showing the slider value

##### Type:

- Node

Source:
  - scale-editor.js, line 41

#### (inner) defaultValue :Float

Initial value of the cell being edited.

##### Type:

- Float

Source:
  - scale-editor.js, line 46